# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISO_SURFACE_METADATA = Metadata(
    id="ae4f55d6aa3df9abb44d283d9623f609eefee601.boutiques",
    name="IsoSurface",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class IsoSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `iso_surface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_ply: OutputPathType
    """Output isosurface in PLY format."""
    output_surface_gii: OutputPathType
    """Output isosurface in GIFTI format."""
    output_surface_stl: OutputPathType
    """Output isosurface in STL format."""


def iso_surface(
    input_vol: InputPathType | None = None,
    shape_spec: list[str] | None = None,
    isorois: bool = False,
    isoval: str | None = None,
    isorange: list[str] | None = None,
    isocmask: str | None = None,
    output_prefix: str | None = None,
    tsmooth: list[str] | None = None,
    debug: str | None = None,
    autocrop: bool = False,
    remesh: str | None = None,
    xform: str | None = None,
    novolreg: bool = False,
    noxform: bool = False,
    runner: Runner | None = None,
) -> IsoSurfaceOutputs:
    """
    A program to perform isosurface extraction from a volume.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_vol: Input volume file.
        shape_spec: Built-in shape specification.
        isorois: Create isosurface for each unique value in the input volume.
        isoval: Create isosurface where volume = V.
        isorange: Create isosurface where V0 <= volume < V1.
        isocmask: Create isosurface where MASK_COM != 0.
        output_prefix: Prefix of output surface file.
        tsmooth: Smooth resultant surface using Taubin smoothing with\
            parameters KPB and NITER.
        debug: Debug levels of 0 (default), 1, 2, 3.
        autocrop: Crop input volume before extraction.
        remesh: Remesh the surface(s).
        xform: Transform to apply to volume values before extracting.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations.
        noxform: Same as -novolreg.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsoSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISO_SURFACE_METADATA)
    cargs = []
    cargs.append("IsoSurface")
    if input_vol is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_vol)
        ])
    if shape_spec is not None:
        cargs.extend([
            "-shape",
            *shape_spec
        ])
    if isorois:
        cargs.append("-isorois")
    if isoval is not None:
        cargs.extend([
            "-isoval",
            isoval
        ])
    if isorange is not None:
        cargs.extend([
            "-isorange",
            *isorange
        ])
    if isocmask is not None:
        cargs.extend([
            "-isocmask",
            isocmask
        ])
    if output_prefix is not None:
        cargs.extend([
            "-o_TYPE",
            output_prefix
        ])
    if tsmooth is not None:
        cargs.extend([
            "-Tsmooth",
            *tsmooth
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            debug
        ])
    if autocrop:
        cargs.append("-autocrop")
    if remesh is not None:
        cargs.extend([
            "-remesh",
            remesh
        ])
    if xform is not None:
        cargs.extend([
            "-xform",
            xform
        ])
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    ret = IsoSurfaceOutputs(
        root=execution.output_file("."),
        output_surface_ply=execution.output_file("[MASK]_surf.ply"),
        output_surface_gii=execution.output_file("[MASK]_surf.gii"),
        output_surface_stl=execution.output_file("[MASK]_surf.stl"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISO_SURFACE_METADATA",
    "IsoSurfaceOutputs",
    "iso_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ASEGSTATS2TABLE_METADATA = Metadata(
    id="75e1aab6262bf11a4bb07f90323b14452beb59b8.boutiques",
    name="asegstats2table",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Asegstats2tableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `asegstats2table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType
    """The resulting table file with segmentation data."""


def asegstats2table(
    tablefile: str,
    subjects: list[str] | None = None,
    inputs: list[str] | None = None,
    subjectsfile: InputPathType | None = None,
    qdec: InputPathType | None = None,
    qdec_long: InputPathType | None = None,
    fsgd: InputPathType | None = None,
    maxsegno: list[str] | None = None,
    segids_from_file: InputPathType | None = None,
    segno_include: list[str] | None = None,
    segno_exclude: list[str] | None = None,
    measure: str | None = None,
    delimiter: str | None = None,
    statsfile: str | None = None,
    subdir: str | None = None,
    scale: float | None = None,
    write_etiv: bool = False,
    debug: bool = False,
    transpose_flag: bool = False,
    common_segs_flag: bool = False,
    all_segs_flag: bool = False,
    no_vol_extras_flag: bool = False,
    skip_missing_flag: bool = False,
    replace53_flag: bool = False,
    runner: Runner | None = None,
) -> Asegstats2tableOutputs:
    """
    Converts a subcortical stats file created by recon-all and/or mri_segstats
    (e.g., aseg.stats) into a table.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        tablefile: The output table file.
        subjects: List of subjects.
        inputs: List of input stat files.
        subjectsfile: Name of the file which has the list of subjects (one\
            subject per line).
        qdec: Name of the qdec table which has the column of subjects ids\
            (fsid).
        qdec_long: Name of the longitudinal qdec table with column of tp ids\
            (fsid) and subject templates (fsid-base).
        fsgd: Name of the FSGD file to extract subjects from.
        maxsegno: Specify the maximum segmentation number.
        segids_from_file: Output only the segmentations present in the\
            specified file.
        segno_include: Include only the specified segmentation IDs.
        segno_exclude: Exclude the specified segmentation IDs.
        measure: Measure to report: default is volume (alternative: mean, std).
        delimiter: Delimiter between measures in the table. Default is tab\
            (alternative: comma, space, semicolon).
        statsfile: Use specified stats file instead of 'aseg.stats'.
        subdir: Use specified subdir instead of 'stats/'.
        scale: Scale factor for all values written to output file. Default is\
            1.
        write_etiv: Report volume as percent estimated total intracranial\
            volume.
        debug: Increase verbosity for debugging purposes.
        transpose_flag: Transpose the table: subjects in columns and\
            segmentations in rows.
        common_segs_flag: Output only the segmentations common to all stats\
            files.
        all_segs_flag: Output all segmentations in the stats files given.
        no_vol_extras_flag: Do not include global volume measures like\
            BrainSegVol.
        skip_missing_flag: Skip subjects that do not have a stats file.
        replace53_flag: Replace 5.3 structure names with later names.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Asegstats2tableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ASEGSTATS2TABLE_METADATA)
    cargs = []
    cargs.append("asegstats2table")
    if subjects is not None:
        cargs.extend([
            "--subjects",
            *subjects
        ])
    if inputs is not None:
        cargs.extend([
            "--inputs",
            *inputs
        ])
    cargs.extend([
        "--tablefile",
        tablefile
    ])
    if subjectsfile is not None:
        cargs.extend([
            "--subjectsfile",
            execution.input_file(subjectsfile)
        ])
    if qdec is not None:
        cargs.extend([
            "--qdec",
            execution.input_file(qdec)
        ])
    if qdec_long is not None:
        cargs.extend([
            "--qdec-long",
            execution.input_file(qdec_long)
        ])
    if fsgd is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgd)
        ])
    if maxsegno is not None:
        cargs.extend([
            "--maxsegno",
            *maxsegno
        ])
    if segids_from_file is not None:
        cargs.extend([
            "--segids-from-file",
            execution.input_file(segids_from_file)
        ])
    if segno_include is not None:
        cargs.extend([
            "--segno",
            *segno_include
        ])
    if segno_exclude is not None:
        cargs.extend([
            "--no-segno",
            *segno_exclude
        ])
    if measure is not None:
        cargs.extend([
            "--meas",
            measure
        ])
    if delimiter is not None:
        cargs.extend([
            "--delimiter",
            delimiter
        ])
    if statsfile is not None:
        cargs.extend([
            "--statsfile",
            statsfile
        ])
    if subdir is not None:
        cargs.extend([
            "--subdir",
            subdir
        ])
    if scale is not None:
        cargs.extend([
            "--scale",
            str(scale)
        ])
    if write_etiv:
        cargs.append("--etiv")
    if debug:
        cargs.append("--debug")
    if transpose_flag:
        cargs.append("--transpose")
    if common_segs_flag:
        cargs.append("--common-segs")
    if all_segs_flag:
        cargs.append("--all-segs")
    if no_vol_extras_flag:
        cargs.append("--no-vol-extras")
    if skip_missing_flag:
        cargs.append("--skip")
    if replace53_flag:
        cargs.append("--replace53")
    ret = Asegstats2tableOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(tablefile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ASEGSTATS2TABLE_METADATA",
    "Asegstats2tableOutputs",
    "asegstats2table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ISOLATE_LABELS_CSH_METADATA = Metadata(
    id="38dc57e5ac2ab0f7a3569ce5a6d3b6708f167dad.boutiques",
    name="isolate_labels.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsolateLabelsCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `isolate_labels_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def isolate_labels_csh(
    label_volume: InputPathType,
    output_prefix: str,
    lowercase_label_option: str | None = None,
    version: bool = False,
    keepval: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> IsolateLabelsCshOutputs:
    """
    Tool to separate out a particular or all labels into individual binary files for
    subsequent shape analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label_volume: Label volume to be analyzed.
        output_prefix: Prefix of binary label file(s).
        lowercase_label_option: The particular label to be analyzed; default is\
            all labels.
        version: Print version and exit.
        keepval: Keeps original label values.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsolateLabelsCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ISOLATE_LABELS_CSH_METADATA)
    cargs = []
    cargs.append("isolate_labels")
    cargs.extend([
        "--vol",
        execution.input_file(label_volume)
    ])
    cargs.extend([
        "--outprefix",
        output_prefix
    ])
    if lowercase_label_option is not None:
        cargs.extend([
            "--l",
            lowercase_label_option
        ])
    if version:
        cargs.append("--version")
    if keepval:
        cargs.append("--keepval")
    if help_:
        cargs.append("--help")
    ret = IsolateLabelsCshOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ISOLATE_LABELS_CSH_METADATA",
    "IsolateLabelsCshOutputs",
    "isolate_labels_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CHECK_SUBJECT_METADATA = Metadata(
    id="a469eabd7979354cb8f4da4909edfba7eca4707c.boutiques",
    name="check_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CheckSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `check_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def check_subject(
    subject_dir: str,
    runner: Runner | None = None,
) -> CheckSubjectOutputs:
    """
    Checks a subject directory for the existence of a surf directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Path to the subject directory to check.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CheckSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CHECK_SUBJECT_METADATA)
    cargs = []
    cargs.append("check_subject")
    cargs.append(subject_dir)
    ret = CheckSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CHECK_SUBJECT_METADATA",
    "CheckSubjectOutputs",
    "check_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_DILATE_METADATA = Metadata(
    id="16a60eaa16b7e968287d378bf5944be258df0be0.boutiques",
    name="metric-dilate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricDilateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_dilate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_dilate(
    metric: InputPathType,
    surface: InputPathType,
    distance: float,
    metric_out: str,
    opt_bad_vertex_roi_roi_metric: InputPathType | None = None,
    opt_data_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_nearest: bool = False,
    opt_linear: bool = False,
    opt_exponent_exponent: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_legacy_cutoff: bool = False,
    runner: Runner | None = None,
) -> MetricDilateOutputs:
    """
    Dilate a metric file.
    
    For all metric vertices that are designated as bad, if they neighbor a
    non-bad vertex with data or are within the specified distance of such a
    vertex, replace the value with a distance-based weighted average of nearby
    non-bad vertices that have data, otherwise set the value to zero. No matter
    how small <distance> is, dilation will always use at least the immediate
    neighbor vertices. If -nearest is specified, it will use the value from the
    closest non-bad vertex with data within range instead of a weighted average.
    
    If -bad-vertex-roi is specified, all vertices with a positive ROI value are
    bad. If it is not specified, only vertices that have data, with a value of
    zero, are bad. If -data-roi is not specified, all vertices are assumed to
    have data.
    
    Note that the -corrected-areas option uses an approximate correction for the
    change in distances along a group average surface.
    
    To get the behavior of version 1.3.2 or earlier, use '-legacy-cutoff
    -exponent 2'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric: the metric to dilate.
        surface: the surface to compute on.
        distance: distance in mm to dilate.
        metric_out: the output metric.
        opt_bad_vertex_roi_roi_metric: specify an roi of vertices to overwrite,\
            rather than vertices with value zero: metric file, positive values\
            denote vertices to have their values replaced.
        opt_data_roi_roi_metric: specify an roi of where there is data: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to dilate: the column number\
            or name.
        opt_nearest: use the nearest good value instead of a weighted average.
        opt_linear: fill in values with linear interpolation along strongest\
            gradient.
        opt_exponent_exponent: use a different exponent in the weighting\
            function: exponent 'n' to use in (area / (distance ^ n)) as the\
            weighting function (default 6).
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_legacy_cutoff: use the v1.3.2 method of choosing how many vertices\
            to use when calulating the dilated value with weighted method.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricDilateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_DILATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-dilate")
    cargs.append(execution.input_file(metric))
    cargs.append(execution.input_file(surface))
    cargs.append(str(distance))
    cargs.append(metric_out)
    if opt_bad_vertex_roi_roi_metric is not None:
        cargs.extend([
            "-bad-vertex-roi",
            execution.input_file(opt_bad_vertex_roi_roi_metric)
        ])
    if opt_data_roi_roi_metric is not None:
        cargs.extend([
            "-data-roi",
            execution.input_file(opt_data_roi_roi_metric)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if opt_nearest:
        cargs.append("-nearest")
    if opt_linear:
        cargs.append("-linear")
    if opt_exponent_exponent is not None:
        cargs.extend([
            "-exponent",
            str(opt_exponent_exponent)
        ])
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    if opt_legacy_cutoff:
        cargs.append("-legacy-cutoff")
    ret = MetricDilateOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_DILATE_METADATA",
    "MetricDilateOutputs",
    "metric_dilate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FUNC2SPH_METADATA = Metadata(
    id="07527586a882465863cf7ef1f979d3d044731e6d.boutiques",
    name="mri-func2sph",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFunc2sphOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_func2sph(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_func2sph(
    instem: str,
    outstem: str,
    hemisphere: typing.Literal["lh", "rh"],
    fvitdir: str,
    hole_filling_iters: float | None = 100,
    icosahedron_size: float | None = 10242,
    input_type: str | None = None,
    umask: str | None = None,
    runner: Runner | None = None,
) -> MriFunc2sphOutputs:
    """
    Maps functional data from volume space to spherical surface space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        instem: Input file stem.
        outstem: Output file stem.
        hemisphere: Hemisphere to process, can be 'lh' or 'rh'.
        fvitdir: Functional vertex information directory.
        hole_filling_iters: Number of hole-filling iterations.
        icosahedron_size: Size of the icosahedron.
        input_type: Type of input data, will be auto-detected if not specified.
        umask: New umask value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFunc2sphOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FUNC2SPH_METADATA)
    cargs = []
    cargs.append("mri-func2sph")
    cargs.extend([
        "-i",
        instem
    ])
    cargs.extend([
        "-o",
        outstem
    ])
    cargs.extend([
        "-hemi",
        hemisphere
    ])
    cargs.extend([
        "-fvitdir",
        fvitdir
    ])
    if hole_filling_iters is not None:
        cargs.extend([
            "-niters",
            str(hole_filling_iters)
        ])
    if icosahedron_size is not None:
        cargs.extend([
            "-icosize",
            str(icosahedron_size)
        ])
    if input_type is not None:
        cargs.extend([
            "-intype",
            input_type
        ])
    if umask is not None:
        cargs.extend([
            "-umask",
            umask
        ])
    ret = MriFunc2sphOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FUNC2SPH_METADATA",
    "MriFunc2sphOutputs",
    "mri_func2sph",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LPCREGISTER_METADATA = Metadata(
    id="e5a5971735d364dfe8f37cf7d53f26828a5b15b4.boutiques",
    name="lpcregister",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LpcregisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `lpcregister(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_reg_file: OutputPathType
    """Output registration file in FreeSurfer format."""
    resampled_volume: OutputPathType | None
    """The resampled movable volume if --o is specified."""


def lpcregister(
    subject_id: str,
    mov_volume: str,
    reg_file: str,
    dof_9: bool = False,
    dof_12: bool = False,
    frame_number: float | None = None,
    mid_frame: bool = False,
    fsvol: str | None = None,
    output_volume: str | None = None,
    tmp_dir: str | None = None,
    no_cleanup: bool = False,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> LpcregisterOutputs:
    """
    Registers a volume to its FreeSurfer anatomical using Local Pearson Correlation
    (LPC) (the AFNI lpc_align.py program). Creates a FreeSurfer register.dat file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID found in SUBJECTS_DIR. The reference volume is\
            the mri/brain volume (modifiable with --fsvol). Converted to analyze\
            using mri_convert.
        mov_volume: Volume identifier of the movable volume. Must be specified\
            suitably for mri_convert. Uses first frame unless --frame is specified.
        reg_file: Output registration file mapping RAS in the reference to RAS\
            in the movable. The file/matrix format is understood by freesurfer.
        dof_9: Use 9 degrees of freedom; default is 6.
        dof_12: Use 12 degrees of freedom; default is 6.
        frame_number: Specify the frame number other than the first. For SPM\
            analyze, specify the file corresponding to the desired frame as each\
            file only has one frame.
        mid_frame: Register to the middle frame of the mov volume as the\
            template. Cannot be used with --frame.
        fsvol: Use FreeSurfer volume id; default is brainmask.
        output_volume: Output volume file for resampled mov.
        tmp_dir: Specify temporary directory (implies --nocleanup).
        no_cleanup: Do not delete temporary files.
        version: Print the version and exit.
        help_: Print help information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LpcregisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LPCREGISTER_METADATA)
    cargs = []
    cargs.append("lpcregister")
    cargs.extend([
        "--s",
        subject_id
    ])
    cargs.extend([
        "--mov",
        mov_volume
    ])
    cargs.extend([
        "--reg",
        reg_file
    ])
    if dof_9:
        cargs.append("--9")
    if dof_12:
        cargs.append("--12")
    if frame_number is not None:
        cargs.extend([
            "--frame",
            str(frame_number)
        ])
    if mid_frame:
        cargs.append("--mid-frame")
    if fsvol is not None:
        cargs.extend([
            "--fsvol",
            fsvol
        ])
    if output_volume is not None:
        cargs.extend([
            "--o",
            output_volume
        ])
    if tmp_dir is not None:
        cargs.extend([
            "--tmp",
            tmp_dir
        ])
    if no_cleanup:
        cargs.append("--nocleanup")
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = LpcregisterOutputs(
        root=execution.output_file("."),
        output_reg_file=execution.output_file("register.dat"),
        resampled_volume=execution.output_file(output_volume) if (output_volume is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LPCREGISTER_METADATA",
    "LpcregisterOutputs",
    "lpcregister",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GCUT_METADATA = Metadata(
    id="2d7a317ffc88d0aa0b30756aff0cdbaa297fc3a1.boutiques",
    name="mri_gcut",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGcutOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gcut(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask_file: OutputPathType
    """The output file containing the skull-stripped brain volume."""


def mri_gcut(
    infile: InputPathType,
    outfile: str,
    wmmask_110: bool = False,
    mult_file: InputPathType | None = None,
    threshold_value: float | None = None,
    runner: Runner | None = None,
) -> MriGcutOutputs:
    """
    Skull stripping algorithm based on graph cuts.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input brain volume file, e.g. T1.mgz.
        outfile: Output file name, e.g. brainmask.auto.mgz.
        wmmask_110: Use voxels with intensity 110 as white matter mask (when\
            applied on T1.mgz, FreeSurfer only).
        mult_file: Intersect the skull-stripped 'in_filename' and an existing\
            skull-stripped volume specified by 'filename', storing the result in\
            'out_filename'.
        threshold_value: Set threshold to value (%) of WM intensity, where the\
            value should be >0 and <1; defaults to 0.40.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGcutOutputs`).
    """
    if threshold_value is not None and not (0 <= threshold_value <= 1): 
        raise ValueError(f"'threshold_value' must be between 0 <= x <= 1 but was {threshold_value}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GCUT_METADATA)
    cargs = []
    cargs.append("mri_gcut")
    if wmmask_110:
        cargs.append("-110")
    if mult_file is not None:
        cargs.extend([
            "-mult",
            execution.input_file(mult_file)
        ])
    if threshold_value is not None:
        cargs.extend([
            "-T",
            str(threshold_value)
        ])
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    ret = MriGcutOutputs(
        root=execution.output_file("."),
        output_mask_file=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GCUT_METADATA",
    "MriGcutOutputs",
    "mri_gcut",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SETLABELSTAT_METADATA = Metadata(
    id="4886639a09879a1b6f761d93393746968357bada.boutiques",
    name="setlabelstat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SetlabelstatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `setlabelstat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType
    """The resulting label file with updated stat values."""


def setlabelstat(
    inlabelfile: InputPathType,
    outlabelfile: InputPathType,
    statval: float,
    help_: bool = False,
    runner: Runner | None = None,
) -> SetlabelstatOutputs:
    """
    Replaces the stat values in a label file with the single stat value supplied on
    the command-line.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inlabelfile: Input label file.
        outlabelfile: Output label file.
        statval: Stat value to replace in the label file.
        help_: Displays help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetlabelstatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SETLABELSTAT_METADATA)
    cargs = []
    cargs.append("setlabelstat")
    cargs.extend([
        "-i",
        execution.input_file(inlabelfile)
    ])
    cargs.extend([
        "-o",
        execution.input_file(outlabelfile)
    ])
    cargs.extend([
        "-s",
        str(statval)
    ])
    if help_:
        cargs.append("-help")
    ret = SetlabelstatOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file(pathlib.Path(outlabelfile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SETLABELSTAT_METADATA",
    "SetlabelstatOutputs",
    "setlabelstat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_MOTION_OUTLIERS_METADATA = Metadata(
    id="f6b6f5bc24c4f96b4e06e73ce63e58c1defb7bdf.boutiques",
    name="fsl_motion_outliers",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslMotionOutliersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_motion_outliers(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_confound_file: OutputPathType
    """Main output confound file"""
    metric_text_file: OutputPathType | None
    """Metric values saved as text file"""
    metric_plot_file: OutputPathType | None
    """Metric values saved as graphical plot (png format)"""


def fsl_motion_outliers(
    input_4d_image: InputPathType,
    output_confound_file: str,
    mask_image: InputPathType | None = None,
    save_metric_file: str | None = None,
    save_metric_plot: str | None = None,
    temp_path: str | None = None,
    refrms_flag: bool = False,
    dvars_flag: bool = False,
    refmse_flag: bool = False,
    fd_flag: bool = False,
    fdrms_flag: bool = False,
    abs_thresh: float | None = None,
    no_moco_flag: bool = False,
    dummy_scans: float | None = None,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> FslMotionOutliersOutputs:
    """
    FSL tool used to calculate motion outliers in 4D image data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_4d_image: Input 4D image (e.g. 4D.nii.gz).
        output_confound_file: Output confound file (e.g. confounds.txt).
        mask_image: Use supplied mask image for calculating metric.
        save_metric_file: Save metric values (e.g. DVARS) as text into\
            specified file.
        save_metric_plot: Save metric values (e.g. DVARS) as a graphical plot\
            (png format).
        temp_path: [Optional] Path to the location where temporary files should\
            be created. Defaults to /tmp.
        refrms_flag: Use RMS intensity difference to reference volume as metric.
        dvars_flag: Use DVARS as metric.
        refmse_flag: Mean Square Error version of --refrms (used in original\
            version of fsl_motion_outliers).
        fd_flag: Use FD (framewise displacement) as metric.
        fdrms_flag: Use FD with RMS matrix calculation as metric.
        abs_thresh: Specify absolute threshold value (otherwise use box-plot\
            cutoff = P75 + 1.5*IQR).
        no_moco_flag: Do not run motion correction (assumed already done).
        dummy_scans: Specify number of dummy scans to delete (before running\
            anything and creating EVs).
        verbose_flag: Verbose mode.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslMotionOutliersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_MOTION_OUTLIERS_METADATA)
    cargs = []
    cargs.append("fsl_motion_outliers")
    cargs.extend([
        "-i",
        execution.input_file(input_4d_image)
    ])
    cargs.extend([
        "-o",
        output_confound_file
    ])
    if mask_image is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_image)
        ])
    if save_metric_file is not None:
        cargs.extend([
            "-s",
            save_metric_file
        ])
    if save_metric_plot is not None:
        cargs.extend([
            "-p",
            save_metric_plot
        ])
    if temp_path is not None:
        cargs.extend([
            "-t",
            temp_path
        ])
    if refrms_flag:
        cargs.append("--refrms")
    if dvars_flag:
        cargs.append("--dvars")
    if refmse_flag:
        cargs.append("--refmse")
    if fd_flag:
        cargs.append("--fd")
    if fdrms_flag:
        cargs.append("--fdrms")
    if abs_thresh is not None:
        cargs.extend([
            "--thresh",
            str(abs_thresh)
        ])
    if no_moco_flag:
        cargs.append("--nomoco")
    if dummy_scans is not None:
        cargs.extend([
            "--dummy",
            str(dummy_scans)
        ])
    if verbose_flag:
        cargs.append("-v")
    ret = FslMotionOutliersOutputs(
        root=execution.output_file("."),
        output_confound_file=execution.output_file(output_confound_file),
        metric_text_file=execution.output_file(save_metric_file) if (save_metric_file is not None) else None,
        metric_plot_file=execution.output_file(save_metric_plot) if (save_metric_plot is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_MOTION_OUTLIERS_METADATA",
    "FslMotionOutliersOutputs",
    "fsl_motion_outliers",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTSUSE_DEFORMATION_FIELD_TO_GET_AFFINE_TRANSFORM_METADATA = Metadata(
    id="a114d5c9bfbab1242b558e6ff3e44480841f6e38.boutiques",
    name="ANTSUseDeformationFieldToGetAffineTransform",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsuseDeformationFieldToGetAffineTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `antsuse_deformation_field_to_get_affine_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_affine_txt: OutputPathType
    """The output is the affine transformation matrix file."""


def antsuse_deformation_field_to_get_affine_transform(
    deformation_field: InputPathType,
    load_ratio: float,
    transform_type: typing.Literal["rigid", "affine"],
    output_affine: str,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> AntsuseDeformationFieldToGetAffineTransformOutputs:
    """
    Extracts an affine transform from a deformation field. The input deformation
    field is expected to be in the same physical space as the images you want to
    transform.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        deformation_field: The input deformation field in NIfTI format (e.g.,\
            zzzWarp.nii.gz).
        load_ratio: Ratio of points to be loaded from deformation field to save\
            memory (ex: 0.01).
        transform_type: Type of transform to be extracted. Can be 'rigid' or\
            'affine'.
        output_affine: The output file where the affine transform will be saved\
            (e.g., OutAffine.txt).
        mask: Optional mask file defining the region from which points will be\
            selected.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsuseDeformationFieldToGetAffineTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTSUSE_DEFORMATION_FIELD_TO_GET_AFFINE_TRANSFORM_METADATA)
    cargs = []
    cargs.append("ANTSUseDeformationFieldToGetAffineTransform")
    cargs.append(execution.input_file(deformation_field))
    cargs.append(str(load_ratio))
    cargs.append(transform_type)
    cargs.append(output_affine)
    if mask is not None:
        cargs.append(execution.input_file(mask))
    ret = AntsuseDeformationFieldToGetAffineTransformOutputs(
        root=execution.output_file("."),
        out_affine_txt=execution.output_file(output_affine),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTSUSE_DEFORMATION_FIELD_TO_GET_AFFINE_TRANSFORM_METADATA",
    "AntsuseDeformationFieldToGetAffineTransformOutputs",
    "antsuse_deformation_field_to_get_affine_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NIML_FEEDME_METADATA = Metadata(
    id="1bac7bbed08a8bb76281f7d7e0ddd7246fef322f.boutiques",
    name="niml_feedme",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NimlFeedmeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `niml_feedme(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def niml_feedme(
    dataset: InputPathType,
    host: str | None = None,
    interval: float | None = None,
    verbose: bool = False,
    accum: bool = False,
    target_dataset: str | None = None,
    drive_cmds: list[str] | None = None,
    runner: Runner | None = None,
) -> NimlFeedmeOutputs:
    """
    Sends volumes from the dataset to AFNI via the NIML socket interface.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset to be sent to AFNI.
        host: Send data, via TCP/IP, to AFNI running on the computer system\
            'sname'. By default, uses the current system (localhost), if you don't\
            use this option.
        interval: Tries to maintain an inter-transmit interval of 'ms'\
            milliseconds. The default is 1000 msec per volume.
        verbose: Be (very) talkative about actions.
        accum: Send sub-bricks so that they accumulate in AFNI. The default is\
            to create only a 1 volume dataset inside AFNI, and each sub-brick just\
            replaces that one volume when it is received.
        target_dataset: Change the dataset name transmitted to AFNI from\
            'niml_feedme' to 'nam'.
        drive_cmds: Send 'cmd' as a DRIVE_AFNI command. If cmd contains blanks,\
            it must be in 'quotes'. Multiple -drive options may be used. These\
            commands will be sent to AFNI just after the first volume is\
            transmitted. See file README.driver for a list of commands.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NimlFeedmeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIML_FEEDME_METADATA)
    cargs = []
    cargs.append("niml_feedme")
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if interval is not None:
        cargs.extend([
            "-dt",
            str(interval)
        ])
    if verbose:
        cargs.append("-verb")
    if accum:
        cargs.append("-accum")
    if target_dataset is not None:
        cargs.extend([
            "-target",
            target_dataset
        ])
    if drive_cmds is not None:
        cargs.extend([
            "-drive",
            *drive_cmds
        ])
    cargs.append(execution.input_file(dataset))
    ret = NimlFeedmeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NIML_FEEDME_METADATA",
    "NimlFeedmeOutputs",
    "niml_feedme",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_Z2P_METADATA = Metadata(
    id="993304b1f6f275d376d70048d9e4d541fe6daff2.boutiques",
    name="mri_z2p",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriZ2pOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_z2p(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_p_volume: OutputPathType
    """Output P volume file."""
    output_sig_volume: OutputPathType
    """Output significance volume file."""


def mri_z2p(
    z_volume: InputPathType,
    p_volume: str,
    sig_volume: str,
    mask_volume: InputPathType | None = None,
    two_sided: bool = False,
    one_sided: bool = False,
    signed: bool = False,
    feat: str | None = None,
    feat_format: str | None = None,
    img_format: bool = False,
    debug: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> MriZ2pOutputs:
    """
    Converts Z-statistic volumes to P-value volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        z_volume: Z volume file.
        p_volume: P volume file.
        sig_volume: Significance volume file.
        mask_volume: Mask volume file.
        two_sided: Assume a two-sided, unsigned test (keeps sign of input).
        one_sided: Assume a one-sided, signed test.
        signed: Two-sided/signed p-value (p = 2*(1-p)).
        feat: Convert all z-stats and zf-stats to sigs in the specified\
            directory.
        feat_format: Use specified format for output (e.g., nii, nii.gz, mgh).
        img_format: Use Analyze output format.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriZ2pOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_Z2P_METADATA)
    cargs = []
    cargs.append("mri_z2p")
    cargs.extend([
        "--z",
        execution.input_file(z_volume)
    ])
    cargs.extend([
        "--p",
        p_volume
    ])
    cargs.extend([
        "--log10p",
        sig_volume
    ])
    if mask_volume is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_volume)
        ])
    if two_sided:
        cargs.append("--two-sided")
    if one_sided:
        cargs.append("--one-sided")
    if signed:
        cargs.append("--signed")
    if feat is not None:
        cargs.extend([
            "--feat",
            feat
        ])
    if feat_format is not None:
        cargs.extend([
            "--featfmt",
            feat_format
        ])
    if img_format:
        cargs.append("--img")
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    ret = MriZ2pOutputs(
        root=execution.output_file("."),
        output_p_volume=execution.output_file(p_volume),
        output_sig_volume=execution.output_file(sig_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_Z2P_METADATA",
    "MriZ2pOutputs",
    "mri_z2p",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SAMSEG_LONG_METADATA = Metadata(
    id="053d1261eca217932b41a5fecb7c25f4e497aefd.boutiques",
    name="run_samseg_long",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSamsegLongOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_samseg_long(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_samseg_long(
    timepoint: list[InputPathType],
    output: str,
    lesion: bool = False,
    threshold: float | None = None,
    samples: float | None = None,
    burnin: float | None = None,
    lesion_mask_structure: str | None = None,
    lesion_mask_pattern: list[float] | None = None,
    mode: list[str] | None = None,
    atlas: str | None = None,
    deformation_hyperprior: float | None = None,
    gmm_hyperprior: float | None = None,
    save_warp: bool = False,
    save_mesh: bool = False,
    save_posteriors: list[str] | None = None,
    pallidum_separate: bool = False,
    threads: float | None = None,
    tp_to_base_transform: list[InputPathType] | None = None,
    force_different_resolutions: bool = False,
    history: bool = False,
    showfigs: bool = False,
    movie: bool = False,
    runner: Runner | None = None,
) -> RunSamsegLongOutputs:
    """
    Longitudinal image segmentation using SAMSEG.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        timepoint: Configure a timepoint with multiple inputs.
        output: Output directory.
        lesion: Enable lesion segmentation (requires tensorflow).
        threshold: Lesion threshold for final segmentation. Requires lesion\
            segmentation.
        samples: Number of samples for lesion segmentation. Requires lesion\
            segmentation.
        burnin: Number of burn-in samples for lesion segmentation. Requires\
            lesion segmentation.
        lesion_mask_structure: Intensity mask brain structure. Requires lesion\
            segmentation.
        lesion_mask_pattern: Lesion mask list: -1 below lesion mask structure\
            mean, +1 above, 0 no mask. Requires lesion segmentation.
        mode: Output basenames for the input image mode.
        atlas: Point to an alternative atlas directory.
        deformation_hyperprior: Strength of the latent deformation hyperprior.
        gmm_hyperprior: Strength of the latent GMM hyperprior.
        save_warp: Save the image->template warp fields.
        save_mesh: Save the final mesh of each timepoint in template space.
        save_posteriors: Save posterior volumes to the 'posteriors'\
            subdirectory.
        pallidum_separate: Move pallidum outside of global white matter class.\
            Use with T2/flair.
        threads: Number of threads to use. Defaults to OMP_NUM_THREADS or 1.
        tp_to_base_transform: Transformation file for each time point to base.
        force_different_resolutions: Force run even if time points have\
            different resolutions.
        history: Save history.
        showfigs: Show figures during run.
        movie: Show history as arrow key controlled time sequence.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSamsegLongOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SAMSEG_LONG_METADATA)
    cargs = []
    cargs.append("run_samseg_long")
    cargs.extend([
        "-t",
        *[execution.input_file(f) for f in timepoint]
    ])
    cargs.extend([
        "-o",
        output
    ])
    if lesion:
        cargs.append("--lesion")
    if threshold is not None:
        cargs.extend([
            "--threshold",
            str(threshold)
        ])
    if samples is not None:
        cargs.extend([
            "--samples",
            str(samples)
        ])
    if burnin is not None:
        cargs.extend([
            "--burnin",
            str(burnin)
        ])
    if lesion_mask_structure is not None:
        cargs.extend([
            "--lesion-mask-structure",
            lesion_mask_structure
        ])
    if lesion_mask_pattern is not None:
        cargs.extend([
            "--lesion-mask-pattern",
            *map(str, lesion_mask_pattern)
        ])
    if mode is not None:
        cargs.extend([
            "-m",
            *mode
        ])
    if atlas is not None:
        cargs.extend([
            "-a",
            atlas
        ])
    if deformation_hyperprior is not None:
        cargs.extend([
            "--deformation-hyperprior",
            str(deformation_hyperprior)
        ])
    if gmm_hyperprior is not None:
        cargs.extend([
            "--gmm-hyperprior",
            str(gmm_hyperprior)
        ])
    if save_warp:
        cargs.append("--save-warp")
    if save_mesh:
        cargs.append("--save-mesh")
    if save_posteriors is not None:
        cargs.extend([
            "--save-posteriors",
            *save_posteriors
        ])
    if pallidum_separate:
        cargs.append("--pallidum-separate")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if tp_to_base_transform is not None:
        cargs.extend([
            "--tp-to-base-transform",
            *[execution.input_file(f) for f in tp_to_base_transform]
        ])
    if force_different_resolutions:
        cargs.append("--force-different-resolutions")
    if history:
        cargs.append("--history")
    if showfigs:
        cargs.append("--showfigs")
    if movie:
        cargs.append("--movie")
    ret = RunSamsegLongOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SAMSEG_LONG_METADATA",
    "RunSamsegLongOutputs",
    "run_samseg_long",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DRIVE_SUMA_METADATA = Metadata(
    id="926f692f4116a5424cd5bd01a3b09ea3e0539288.boutiques",
    name="DriveSuma",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DriveSumaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `drive_suma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def drive_suma(
    command: str,
    surf_label: str | None = None,
    surface_file: InputPathType | None = None,
    surf_state: str | None = None,
    surf_winding: str | None = None,
    coordinates: InputPathType | None = None,
    autorecord: str | None = None,
    background_color: str | None = None,
    view_file: InputPathType | None = None,
    do_file: InputPathType | None = None,
    do_draw_mask: str | None = None,
    fixed_do: str | None = None,
    mobile_do: str | None = None,
    key_press: str | None = None,
    viewer: str | None = None,
    anim_dup: float | None = None,
    save_as: str | None = None,
    save_index: float | None = None,
    save_range: str | None = None,
    save_last: bool = False,
    save_last_n: float | None = None,
    save_all: bool = False,
    echo_edu: bool = False,
    echo_nel_stdout: bool = False,
    echo_nel_stderr: bool = False,
    examples: bool = False,
    help_: bool = False,
    h: bool = False,
    help_nido: bool = False,
    c_demo: bool = False,
    viewer_cont: bool = False,
    runner: Runner | None = None,
) -> DriveSumaOutputs:
    """
    A program to drive suma from the command line.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        command: Command to be sent to SUMA.
        surf_label: A label (identifier) to assign to the surface.
        surface_file: Name of surface file.
        surf_state: Name the state of that surface.
        surf_winding: Winding of triangles (ccw or cw).
        coordinates: A 1D formatted file containing new coordinates for nodes.
        autorecord: Set the autorecord prefix.
        background_color: Set the background color (R G B).
        view_file: Load a previously saved view file.
        do_file: Load a displayable object file.
        do_draw_mask: Restrict where DO node-based objects are displayed.
        fixed_do: Load a fixed coordinate type NIML DO.
        mobile_do: Mobile version of fixed_do.
        key_press: Act as if a key press was applied in the viewer.
        viewer: Specify which viewer should be acted upon.
        anim_dup: Save DUP copies of each frame into movie.
        save_as: Save image(s) in recorder in specified format.
        save_index: Save one image indexed IND.
        save_range: Save images from FROM to TO.
        save_last: Save last image.
        save_last_n: Save last N images.
        save_all: Save all images.
        echo_edu: Echoes the entire command line for edification purposes.
        echo_nel_stdout: Spit out the NIML object being sent to SUMA to stdout.
        echo_nel_stderr: Spit out the NIML object being sent to SUMA to stderr.
        examples: Show all the sample commands and exit.
        help_: Show the help in detail.
        h: Show help with slightly less detail.
        help_nido: Show the help for NIML Displayable Objects and exit.
        c_demo: Execute a preset number of commands to illustrate how one can\
            communicate with SUMA from one's own C code.
        viewer_cont: Apply settings to viewer or viewer controller.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DriveSumaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DRIVE_SUMA_METADATA)
    cargs = []
    cargs.append("DriveSuma")
    cargs.append(command)
    if surf_label is not None:
        cargs.extend([
            "-surf_label",
            surf_label
        ])
    if surface_file is not None:
        cargs.extend([
            "-i_TYPE",
            execution.input_file(surface_file)
        ])
    if surf_state is not None:
        cargs.extend([
            "-surf_state",
            surf_state
        ])
    if surf_winding is not None:
        cargs.extend([
            "-surf_winding",
            surf_winding
        ])
    if coordinates is not None:
        cargs.extend([
            "-xyz_1D",
            execution.input_file(coordinates)
        ])
    if autorecord is not None:
        cargs.extend([
            "-autorecord",
            autorecord
        ])
    if background_color is not None:
        cargs.extend([
            "-bkg_col",
            background_color
        ])
    if view_file is not None:
        cargs.extend([
            "-load_view",
            execution.input_file(view_file)
        ])
    if do_file is not None:
        cargs.extend([
            "-load_do",
            execution.input_file(do_file)
        ])
    if do_draw_mask is not None:
        cargs.extend([
            "-do_draw_mask",
            do_draw_mask
        ])
    if fixed_do is not None:
        cargs.extend([
            "-fixed_do",
            fixed_do
        ])
    if mobile_do is not None:
        cargs.extend([
            "-mobile_do",
            mobile_do
        ])
    if key_press is not None:
        cargs.extend([
            "-key",
            key_press
        ])
    if viewer is not None:
        cargs.extend([
            "-viewer",
            viewer
        ])
    if anim_dup is not None:
        cargs.extend([
            "-anim_dup",
            str(anim_dup)
        ])
    if save_as is not None:
        cargs.extend([
            "-save_as",
            save_as
        ])
    if save_index is not None:
        cargs.extend([
            "-save_index",
            str(save_index)
        ])
    if save_range is not None:
        cargs.extend([
            "-save_range",
            save_range
        ])
    if save_last:
        cargs.append("-save_last")
    if save_last_n is not None:
        cargs.extend([
            "-save_last_n",
            str(save_last_n)
        ])
    if save_all:
        cargs.append("-save_all")
    if echo_edu:
        cargs.append("-echo_edu")
    if echo_nel_stdout:
        cargs.append("-echo_nel_stdout")
    if echo_nel_stderr:
        cargs.append("-echo_nel_stderr")
    if examples:
        cargs.append("-examples")
    if help_:
        cargs.append("-help")
    if h:
        cargs.append("-h")
    if help_nido:
        cargs.append("-help_nido")
    if c_demo:
        cargs.append("-C_demo")
    if viewer_cont:
        cargs.append("-com viewer_cont")
    ret = DriveSumaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DRIVE_SUMA_METADATA",
    "DriveSumaOutputs",
    "drive_suma",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CLUST_SIM_METADATA = Metadata(
    id="493de4c7d1501714af71d386a011e1fe097ca5fb.boutiques",
    name="3dClustSim",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dClustSimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_clust_sim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_nn1_1sided: OutputPathType
    """Output file for NN1 with 1-sided thresholding"""
    output_nn1_2sided: OutputPathType
    """Output file for NN1 with 2-sided thresholding"""
    output_nn1_bisided: OutputPathType
    """Output file for NN1 with bi-sided thresholding"""
    output_nn2_1sided: OutputPathType
    """Output file for NN2 with 1-sided thresholding"""
    output_nn2_2sided: OutputPathType
    """Output file for NN2 with 2-sided thresholding"""
    output_nn2_bisided: OutputPathType
    """Output file for NN2 with bi-sided thresholding"""
    output_nn3_1sided: OutputPathType
    """Output file for NN3 with 1-sided thresholding"""
    output_nn3_2sided: OutputPathType
    """Output file for NN3 with 2-sided thresholding"""
    output_nn3_bisided: OutputPathType
    """Output file for NN3 with bi-sided thresholding"""
    mask_compressed: OutputPathType
    """Compressed ASCII encoding of the mask volume"""


def v_3d_clust_sim(
    runner: Runner | None = None,
) -> V3dClustSimOutputs:
    """
    Program to estimate the probability of false positive (noise-only) clusters.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dClustSimOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CLUST_SIM_METADATA)
    cargs = []
    cargs.append("3dClustSim")
    cargs.append("[OPTIONS]")
    ret = V3dClustSimOutputs(
        root=execution.output_file("."),
        output_nn1_1sided=execution.output_file("[PREFIX].NN1_1sided.1D"),
        output_nn1_2sided=execution.output_file("[PREFIX].NN1_2sided.1D"),
        output_nn1_bisided=execution.output_file("[PREFIX].NN1_bisided.1D"),
        output_nn2_1sided=execution.output_file("[PREFIX].NN2_1sided.1D"),
        output_nn2_2sided=execution.output_file("[PREFIX].NN2_2sided.1D"),
        output_nn2_bisided=execution.output_file("[PREFIX].NN2_bisided.1D"),
        output_nn3_1sided=execution.output_file("[PREFIX].NN3_1sided.1D"),
        output_nn3_2sided=execution.output_file("[PREFIX].NN3_2sided.1D"),
        output_nn3_bisided=execution.output_file("[PREFIX].NN3_bisided.1D"),
        mask_compressed=execution.output_file("[PREFIX].mask"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dClustSimOutputs",
    "V_3D_CLUST_SIM_METADATA",
    "v_3d_clust_sim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_VOLMASK_VTK_METADATA = Metadata(
    id="800007184636ff21baf1531ccc9b9b9b778933b9.boutiques",
    name="mris_volmask_vtk",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisVolmaskVtkOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_volmask_vtk(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_mask: OutputPathType | None
    """Output volume mask file."""
    left_ribbon_output: OutputPathType | None
    """Left hemisphere ribbon output file."""
    right_ribbon_output: OutputPathType | None
    """Right hemisphere ribbon output file."""
    edited_aseg_output: OutputPathType
    """Edited aseg output using ribbons."""
    dwhite_output: OutputPathType
    """Signed distance output for the white matter."""
    dpial_output: OutputPathType
    """Signed distance output for the pial surface."""


def mris_volmask_vtk(
    io_param: str,
    cap_distance: float | None = None,
    label_background: float | None = None,
    label_left_white: float | None = None,
    label_left_ribbon: float | None = None,
    label_right_white: float | None = None,
    label_right_ribbon: float | None = None,
    surf_white: str | None = None,
    surf_pial: str | None = None,
    aseg_name: str | None = None,
    out_root: str | None = None,
    subjects_dir: str | None = None,
    save_distance: bool = False,
    lh_only: bool = False,
    rh_only: bool = False,
    parallel: bool = False,
    edit_aseg: bool = False,
    save_ribbon: bool = False,
    runner: Runner | None = None,
) -> MrisVolmaskVtkOutputs:
    """
    Computes a volume mask at the resolution of the brain.mgz file, containing
    labels for various brain structures using surface files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        io_param: Input-Output parameter as positional argument.
        cap_distance: Maximum distance up to which the signed distance function\
            computation is accurate.
        label_background: Override the default background label value (0).
        label_left_white: Override the default left white matter label (20).
        label_left_ribbon: Override the default left ribbon label (10).
        label_right_white: Override the default right white matter label (120).
        label_right_ribbon: Override the default right ribbon label (110).
        surf_white: Surface root name for white matter surfaces (default:\
            white).
        surf_pial: Surface root name for pial surfaces (default: pial).
        aseg_name: Specify a different name for the aseg input file (default:\
            aseg).
        out_root: Output root name (default: ribbon) for generated output\
            files.
        subjects_dir: Specify the SUBJECTS_DIR, default is read from\
            environment.
        save_distance: Option to save the signed distance function.
        lh_only: Only process left hemisphere.
        rh_only: Only process right hemisphere.
        parallel: Run hemispheres in parallel and combine the result.
        edit_aseg: Edit the aseg using the ribbons and save it.
        save_ribbon: Save only the ribbon for the hemispheres.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisVolmaskVtkOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_VOLMASK_VTK_METADATA)
    cargs = []
    cargs.append("mris_volmask")
    if cap_distance is not None:
        cargs.extend([
            "--cap_distance",
            str(cap_distance)
        ])
    if label_background is not None:
        cargs.extend([
            "--label_background",
            str(label_background)
        ])
    if label_left_white is not None:
        cargs.extend([
            "--label_left_white",
            str(label_left_white)
        ])
    if label_left_ribbon is not None:
        cargs.extend([
            "--label_left_ribbon",
            str(label_left_ribbon)
        ])
    if label_right_white is not None:
        cargs.extend([
            "--label_right_white",
            str(label_right_white)
        ])
    if label_right_ribbon is not None:
        cargs.extend([
            "--label_right_ribbon",
            str(label_right_ribbon)
        ])
    if surf_white is not None:
        cargs.extend([
            "--surf_white",
            surf_white
        ])
    if surf_pial is not None:
        cargs.extend([
            "--surf_pial",
            surf_pial
        ])
    if aseg_name is not None:
        cargs.extend([
            "--aseg_name",
            aseg_name
        ])
    if out_root is not None:
        cargs.extend([
            "--out_root",
            out_root
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if save_distance:
        cargs.append("--save_distance")
    if lh_only:
        cargs.append("--lh-only")
    if rh_only:
        cargs.append("--rh-only")
    if parallel:
        cargs.append("--parallel")
    if edit_aseg:
        cargs.append("--edit_aseg")
    if save_ribbon:
        cargs.append("--save_ribbon")
    cargs.append(io_param)
    ret = MrisVolmaskVtkOutputs(
        root=execution.output_file("."),
        output_volume_mask=execution.output_file("mri/" + out_root + ".mgz") if (out_root is not None) else None,
        left_ribbon_output=execution.output_file("mri/lh." + out_root + ".mgz") if (out_root is not None) else None,
        right_ribbon_output=execution.output_file("mri/rh." + out_root + ".mgz") if (out_root is not None) else None,
        edited_aseg_output=execution.output_file("mri/aseg.ribbon.mgz"),
        dwhite_output=execution.output_file("mri/?h.dwhite.mgz"),
        dpial_output=execution.output_file("mri/?h.dpial.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_VOLMASK_VTK_METADATA",
    "MrisVolmaskVtkOutputs",
    "mris_volmask_vtk",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_LEFT_RIGHT_REGISTER_METADATA = Metadata(
    id="a4c6b07b104f5a2cf15152261803ae81014407e6.boutiques",
    name="mris_left_right_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisLeftRightRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_left_right_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_lh_sphere_left_right: OutputPathType
    """Registered left hemisphere spherical surface output file"""
    out_rh_sphere_left_right: OutputPathType
    """Registered right hemisphere spherical surface output file"""


def mris_left_right_register(
    lh_sphere: InputPathType,
    rh_sphere: InputPathType,
    lh_sphere_left_right: str,
    rh_sphere_left_right: str,
    runner: Runner | None = None,
) -> MrisLeftRightRegisterOutputs:
    """
    Register left and right hemisphere spherical surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        lh_sphere: Left hemisphere spherical surface input file.
        rh_sphere: Right hemisphere spherical surface input file.
        lh_sphere_left_right: Output file for left hemisphere with left-right\
            registration.
        rh_sphere_left_right: Output file for right hemisphere with left-right\
            registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisLeftRightRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_LEFT_RIGHT_REGISTER_METADATA)
    cargs = []
    cargs.append("mris_left_right_register")
    cargs.append(execution.input_file(lh_sphere))
    cargs.append(execution.input_file(rh_sphere))
    cargs.append(lh_sphere_left_right)
    cargs.append(rh_sphere_left_right)
    ret = MrisLeftRightRegisterOutputs(
        root=execution.output_file("."),
        out_lh_sphere_left_right=execution.output_file(lh_sphere_left_right),
        out_rh_sphere_left_right=execution.output_file(rh_sphere_left_right),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_LEFT_RIGHT_REGISTER_METADATA",
    "MrisLeftRightRegisterOutputs",
    "mris_left_right_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLVAL_METADATA = Metadata(
    id="8a100481b1c8accf8862e7e516017aa7a9142b94.boutiques",
    name="fslval",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslvalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """Output printed to standard out"""


def fslval(
    input_file: InputPathType,
    keyword_: str,
    runner: Runner | None = None,
) -> FslvalOutputs:
    """
    Tool for printing out header information from NIfTI image files.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input NIfTI image file.
        keyword_: Keyword to query from the NIfTI header.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslvalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLVAL_METADATA)
    cargs = []
    cargs.append("fslval")
    cargs.append(execution.input_file(input_file))
    cargs.append(keyword_)
    ret = FslvalOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLVAL_METADATA",
    "FslvalOutputs",
    "fslval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_AVERAGE_VOLUME_METADATA = Metadata(
    id="52d00009c5f5db471f13423dea8699f07efa357d.boutiques",
    name="make_average_volume",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeAverageVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_average_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def make_average_volume(
    subjects: list[str],
    fsgd: InputPathType | None = None,
    out: str | None = None,
    topdir: str | None = None,
    xform: str | None = None,
    sdir: str | None = None,
    force_flag: bool = False,
    keep_all_orig_flag: bool = False,
    no_aseg_flag: bool = False,
    ctab: str | None = None,
    ctab_default_flag: bool = False,
    echo_flag: bool = False,
    nocleanup_flag: bool = False,
    runner: Runner | None = None,
) -> MakeAverageVolumeOutputs:
    """
    Creates average volumes from a set of subjects.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subjects to include in the average.
        fsgd: File containing subject list for averaging.
        out: Output average subject name. Default is 'average'.
        topdir: Directory to put data and link to SUBJECTS_DIR.
        xform: Transformation name to use, default is talairach.xfm.
        sdir: Use specified SUBJECTS_DIR instead of the environment's one.
        force_flag: Overwrite existing average subject data.
        keep_all_orig_flag: Concatenate all original volumes into\
            mri/orig.all.mgz.
        no_aseg_flag: Do not create 'average' aseg.
        ctab: Embed colortable into segmentations.
        ctab_default_flag: Embed FreeSurferColorLUT.txt into segmentations.
        echo_flag: Enable command echo for debugging.
        nocleanup_flag: Do not delete temporary files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeAverageVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_AVERAGE_VOLUME_METADATA)
    cargs = []
    cargs.append("make_average_volume")
    cargs.extend([
        "--subjects",
        *subjects
    ])
    if fsgd is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgd)
        ])
    if out is not None:
        cargs.extend([
            "--out",
            out
        ])
    if topdir is not None:
        cargs.extend([
            "--topdir",
            topdir
        ])
    if xform is not None:
        cargs.extend([
            "--xform",
            xform
        ])
    if sdir is not None:
        cargs.extend([
            "--sdir",
            sdir
        ])
    if force_flag:
        cargs.append("--force")
    if keep_all_orig_flag:
        cargs.append("--keep-all-orig")
    if no_aseg_flag:
        cargs.append("--no-aseg")
    if ctab is not None:
        cargs.extend([
            "--ctab",
            ctab
        ])
    if ctab_default_flag:
        cargs.append("--ctab-default")
    if echo_flag:
        cargs.append("--echo")
    if nocleanup_flag:
        cargs.append("--nocleanup")
    ret = MakeAverageVolumeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_AVERAGE_VOLUME_METADATA",
    "MakeAverageVolumeOutputs",
    "make_average_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_VOLSMOOTH_METADATA = Metadata(
    id="e771a27b746ea9fefc370e231755f9773a9c0720.boutiques",
    name="mris_volsmooth",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisVolsmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_volsmooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outvol_file: OutputPathType
    """Output volume file after surface-based smoothing."""
    lh_surface_output: OutputPathType | None
    """Left hemisphere smoothed surface output."""
    rh_surface_output: OutputPathType | None
    """Right hemisphere smoothed surface output."""


def mris_volsmooth(
    input_volume: InputPathType,
    output_volume: str,
    registration: InputPathType,
    projfrac: float | None = None,
    projfrac_avg: str | None = None,
    fill_ribbon: bool = False,
    surf_out: str | None = None,
    fwhm: float | None = None,
    niters: float | None = None,
    vol_fwhm: float | None = None,
    log: str | None = None,
    nocleanup: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> MrisVolsmoothOutputs:
    """
    Performs surface-based smoothing inside a volume by sampling a volume to a
    surface, smoothing on the surface, then replacing the surface voxels in the
    volume with values that were smoothed.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Source volume with values that will be smoothed on the\
            surface.
        output_volume: Output volume.
        registration: TKRegister-style registration matrix that maps between\
            the input/output volumes and the FreeSurfer surface anatomical.
        projfrac: Fraction of thickness to project along surface normal.
        projfrac_avg: Average sampling along normal, specified by min, max, and\
            delta.
        fill_ribbon: Fill ribbon.
        surf_out: Save smoothed surfaces as basename.?h.mgh.
        fwhm: Surface smoothing by full-width/half-max in mm.
        niters: Specify surface smoothing by number of nearest neighbor\
            smoothing iterations.
        vol_fwhm: Volume smoothing outside of the surface. Surface voxels and\
            non-surface voxels are smoothed separately.
        log: Explicitly set log file.
        nocleanup: Do not delete temporary files.
        debug: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisVolsmoothOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_VOLSMOOTH_METADATA)
    cargs = []
    cargs.append("mris_volsmooth")
    cargs.extend([
        "-i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "-o",
        output_volume
    ])
    cargs.extend([
        "-reg",
        execution.input_file(registration)
    ])
    if projfrac is not None:
        cargs.extend([
            "--projfrac",
            str(projfrac)
        ])
    if projfrac_avg is not None:
        cargs.extend([
            "--projfrac-avg",
            projfrac_avg
        ])
    if fill_ribbon:
        cargs.append("--fill-ribbon")
    if surf_out is not None:
        cargs.extend([
            "--surf-out",
            surf_out
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if niters is not None:
        cargs.extend([
            "--niters",
            str(niters)
        ])
    if vol_fwhm is not None:
        cargs.extend([
            "--vol-fwhm",
            str(vol_fwhm)
        ])
    if log is not None:
        cargs.extend([
            "--log",
            log
        ])
    if nocleanup:
        cargs.append("--nocleanup")
    if debug:
        cargs.append("--debug")
    ret = MrisVolsmoothOutputs(
        root=execution.output_file("."),
        outvol_file=execution.output_file(output_volume + ".mgh"),
        lh_surface_output=execution.output_file(surf_out + ".lh.mgh") if (surf_out is not None) else None,
        rh_surface_output=execution.output_file(surf_out + ".rh.mgh") if (surf_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_VOLSMOOTH_METADATA",
    "MrisVolsmoothOutputs",
    "mris_volsmooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SEGMENT_METADATA = Metadata(
    id="874f399dc8d69d96d209aceed20b75e4de0707c9.boutiques",
    name="mris_segment",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSegmentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_segment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmented_output: OutputPathType
    """Segmented surfaces output file"""


def mris_segment(
    subjects: list[str],
    output_subject: str,
    output_file: str,
    runner: Runner | None = None,
) -> MrisSegmentOutputs:
    """
    A command-line tool for segmenting surfaces in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: A list of input subjects.
        output_subject: Output subject name.
        output_file: Output file path.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSegmentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SEGMENT_METADATA)
    cargs = []
    cargs.append("mris_segment")
    cargs.extend(subjects)
    cargs.append(output_subject)
    cargs.append(output_file)
    ret = MrisSegmentOutputs(
        root=execution.output_file("."),
        segmented_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SEGMENT_METADATA",
    "MrisSegmentOutputs",
    "mris_segment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MEAN_METADATA = Metadata(
    id="e324408a8ad006ebdb33f912bb6b96f4f9350026.boutiques",
    name="3dMean",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMeanOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mean(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output dataset"""


def v_3d_mean(
    input_files: list[InputPathType],
    verbose: bool = False,
    prefix: str | None = None,
    datum: str | None = None,
    fscale: bool = False,
    gscale: bool = False,
    nscale: bool = False,
    non_zero: bool = False,
    stdev: bool = False,
    sqr: bool = False,
    sum_: bool = False,
    count: bool = False,
    max_: bool = False,
    min_: bool = False,
    absmax: bool = False,
    signed_absmax: bool = False,
    mask_inter: bool = False,
    mask_union: bool = False,
    weightset: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dMeanOutputs:
    """
    Takes the voxel-by-voxel mean of all input datasets; designed to be faster than
    3dcalc.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets.
        verbose: Print out some information along the way.
        prefix: Sets the prefix of the output dataset.
        datum: Sets the datum of the output dataset.
        fscale: Force scaling of the output to the maximum integer range.
        gscale: Force scaling of the output to the maximum integer range, with\
            uniform scaling factor for each sub-brick.
        nscale: Don't do any scaling on output to byte or short datasets. Only\
            use if you want the output dataset to be integer-valued.
        non_zero: Use only non-zero values for calculation of mean, min, max,\
            sum, squares.
        stdev: Calculate the standard deviation, sqrt(variance), instead of the\
            mean (cannot be used with -sqr, -sum or -non_zero).
        sqr: Average the squares, instead of the values.
        sum_: Just take the sum (don't divide by number of datasets).
        count: Compute only the count of non-zero voxels.
        max_: Find the maximum at each voxel.
        min_: Find the minimum at each voxel.
        absmax: Find maximum absolute value at each voxel.
        signed_absmax: Find extremes with maximum absolute value but preserve\
            sign.
        mask_inter: Create a simple intersection mask.
        mask_union: Create a simple union mask.
        weightset: Sum of N dsets will be weighted by N volume WSET. This\
            weight dataset must be of type float.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMeanOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MEAN_METADATA)
    cargs = []
    cargs.append("3dMean")
    cargs.extend([execution.input_file(f) for f in input_files])
    if verbose:
        cargs.append("-verbose")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if fscale:
        cargs.append("-fscale")
    if gscale:
        cargs.append("-gscale")
    if nscale:
        cargs.append("-nscale")
    if non_zero:
        cargs.append("-non_zero")
    if stdev:
        cargs.append("-sd")
    if sqr:
        cargs.append("-sqr")
    if sum_:
        cargs.append("-sum")
    if count:
        cargs.append("-count")
    if max_:
        cargs.append("-max")
    if min_:
        cargs.append("-min")
    if absmax:
        cargs.append("-absmax")
    if signed_absmax:
        cargs.append("-signed_absmax")
    if mask_inter:
        cargs.append("-mask_inter")
    if mask_union:
        cargs.append("-mask_union")
    if weightset is not None:
        cargs.extend([
            "-weightset",
            execution.input_file(weightset)
        ])
    ret = V3dMeanOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + "<+optional_extension>") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMeanOutputs",
    "V_3D_MEAN_METADATA",
    "v_3d_mean",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COREG_METADATA = Metadata(
    id="057f6d3fb653672744b9e6411c4faf5cf046f03e.boutiques",
    name="mri_coreg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCoregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_coreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_registration: OutputPathType
    """Output registration (LTA format)"""
    out_params: OutputPathType | None
    """File with output parameters"""
    out_cost: OutputPathType | None
    """Final cost value file"""
    saved_init_reg: OutputPathType | None
    """Saved initial registration"""
    saved_init_reg_only: OutputPathType | None
    """Saved initial registration (exit after save)"""
    movout_volume: OutputPathType | None
    """Preprocessed moving volume"""
    mov_idither_volume: OutputPathType | None
    """Moving intensity dither volume"""


def mri_coreg(
    movvol: InputPathType,
    refvol: InputPathType,
    reg: str,
    subject: str | None = None,
    dof: int | None = None,
    zscale: bool = False,
    xztrans_yrot: bool = False,
    xytrans_zrot: bool = False,
    xytrans_zrot_xyscale_xyshear: bool = False,
    ref_maskvol: InputPathType | None = None,
    no_ref_mask: bool = False,
    mov_maskvol: InputPathType | None = None,
    threads: int | None = None,
    subjects_dir: str | None = None,
    regdat: str | None = None,
    no_coord_dither: bool = False,
    no_intensity_dither: bool = False,
    spatial_scales: list[str] | None = None,
    trans: list[float] | None = None,
    rot: list[float] | None = None,
    scale: list[float] | None = None,
    shear: list[float] | None = None,
    init_reg: InputPathType | None = None,
    out_param_file: str | None = None,
    out_cost_file: str | None = None,
    no_cras0: bool = False,
    centroid: bool = False,
    ras2ras: bool = False,
    nitersmax: int | None = None,
    ftol: float | None = None,
    linmintol: float | None = None,
    seed: int | None = None,
    sat: float | None = None,
    conf_ref: bool = False,
    no_bf: bool = False,
    bf_lim: float | None = None,
    bf_nsamp: int | None = None,
    no_smooth: bool = False,
    ref_fwhm: float | None = None,
    mov_oob: bool = False,
    init_reg_save: InputPathType | None = None,
    init_reg_save_only: InputPathType | None = None,
    mat2par: InputPathType | None = None,
    mat2rot: InputPathType | None = None,
    par2mat: str | None = None,
    lrrev: InputPathType | None = None,
    landmarks: list[str] | None = None,
    rms: list[str] | None = None,
    movout: InputPathType | None = None,
    mov_idither: InputPathType | None = None,
    debug: bool = False,
    checkopts: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriCoregOutputs:
    """
    mri_coreg performs a linear registration between two volumes using the method
    compatible with spm_coreg.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        movvol: Source volume (mov).
        refvol: Target volume (ref or targ).
        reg: Output registration file.
        subject: Subject ID, forces --ref-mask aparc+aseg.mgz.
        dof: Degrees of freedom. Default is 6.
        zscale: Enable 7 dof registration with scaling in Z.
        xztrans_yrot: For 2D images: uses shifts in x and z and rotation about\
            y (no scale).
        xytrans_zrot: For 2D images: uses shifts in x and y and rotation about\
            z (no scale).
        xytrans_zrot_xyscale_xyshear: For 2D images: uses shifts in x and y,\
            rotation about z, scale in xy, and xy shear.
        ref_maskvol: Mask reference volume with specified mask volume.
        no_ref_mask: Do not mask reference volume.
        mov_maskvol: Mask moving volume with specified mask volume.
        threads: Number of threads to use.
        subjects_dir: Freesurfer SUBJECTS_DIR.
        regdat: Specify registration data file.
        no_coord_dither: Turn off coordinate dithering.
        no_intensity_dither: Turn off intensity dithering.
        spatial_scales: Set spatial scales.
        trans: Initial translation in mm.
        rot: Initial rotation in degrees.
        scale: Initial scale.
        shear: Initial shear.
        init_reg: Initialize with given registration file.
        out_param_file: Save parameters in specified file.
        out_cost_file: Save final cost value in specified file.
        no_cras0: Do not set translation parameters to align centers of mov and\
            ref.
        centroid: Initialize by aligning centroids of mov and ref.
        ras2ras: Save output LTA as RAS2RAS.
        nitersmax: Set maximum number of iterations.
        ftol: Set function tolerance.
        linmintol: Set line minimum tolerance.
        seed: Set random seed for dithering.
        sat: Set saturation threshold.
        conf_ref: Conform the reference without rescaling.
        no_bf: Do not perform brute force search.
        bf_lim: Set constraint limits for brute force search.
        bf_nsamp: Set number of samples for brute force search.
        no_smooth: Do not apply smoothing to either ref or mov.
        ref_fwhm: Apply smoothing to ref with specified FWHM.
        mov_oob: Count mov voxels that are out-of-bounds as 0.
        init_reg_save: Save initial registration.
        init_reg_save_only: Save initial registration and exit.
        mat2par: Extract parameters out of registration.
        mat2rot: Convert registration to a pure rotation.
        par2mat: Convert parameters to a registration.
        lrrev: Approximate registration if you were to left-right reverse the\
            pixels of the input image.
        landmarks: Convert landmarks to a registration.
        rms: Compute RMS difference between two registrations.
        movout: Save the mov after all preprocessing steps.
        mov_idither: Save the mov intensity dither volume.
        debug: Enable debugging mode.
        checkopts: Check options and exit without running.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCoregOutputs`).
    """
    if spatial_scales is not None and not (1 <= len(spatial_scales) <= 2): 
        raise ValueError(f"Length of 'spatial_scales' must be between 1 and 2 but was {len(spatial_scales)}")
    if landmarks is not None and not (6 <= len(landmarks)): 
        raise ValueError(f"Length of 'landmarks' must be greater than 6 but was {len(landmarks)}")
    if rms is not None and not (4 <= len(rms)): 
        raise ValueError(f"Length of 'rms' must be greater than 4 but was {len(rms)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COREG_METADATA)
    cargs = []
    cargs.append("mri_coreg")
    cargs.extend([
        "-mov",
        execution.input_file(movvol)
    ])
    cargs.extend([
        "-ref",
        execution.input_file(refvol)
    ])
    cargs.extend([
        "-reg",
        reg
    ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if dof is not None:
        cargs.extend([
            "--dof",
            str(dof)
        ])
    if zscale:
        cargs.append("--zscale")
    if xztrans_yrot:
        cargs.append("--xztrans+yrot")
    if xytrans_zrot:
        cargs.append("--xytrans+zrot")
    if xytrans_zrot_xyscale_xyshear:
        cargs.append("--xytrans+zrot+xyscale+xyshear")
    if ref_maskvol is not None:
        cargs.extend([
            "--ref-mask",
            execution.input_file(ref_maskvol)
        ])
    if no_ref_mask:
        cargs.append("--no-ref-mask")
    if mov_maskvol is not None:
        cargs.extend([
            "--mov-mask",
            execution.input_file(mov_maskvol)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if regdat is not None:
        cargs.extend([
            "--regdat",
            regdat
        ])
    if no_coord_dither:
        cargs.append("--no-coord-dither")
    if no_intensity_dither:
        cargs.append("--no-intensity-dither")
    if spatial_scales is not None:
        cargs.extend([
            "--sep",
            *spatial_scales
        ])
    if trans is not None:
        cargs.extend([
            "--trans",
            *map(str, trans)
        ])
    if rot is not None:
        cargs.extend([
            "--rot",
            *map(str, rot)
        ])
    if scale is not None:
        cargs.extend([
            "--scale",
            *map(str, scale)
        ])
    if shear is not None:
        cargs.extend([
            "--shear",
            *map(str, shear)
        ])
    if init_reg is not None:
        cargs.extend([
            "--init-reg",
            execution.input_file(init_reg)
        ])
    if out_param_file is not None:
        cargs.extend([
            "--params",
            out_param_file
        ])
    if out_cost_file is not None:
        cargs.extend([
            "--final-cost",
            out_cost_file
        ])
    if no_cras0:
        cargs.append("--no-cras0")
    if centroid:
        cargs.append("--centroid")
    if ras2ras:
        cargs.append("--ras2ras")
    if nitersmax is not None:
        cargs.extend([
            "--nitersmax",
            str(nitersmax)
        ])
    if ftol is not None:
        cargs.extend([
            "--ftol",
            str(ftol)
        ])
    if linmintol is not None:
        cargs.extend([
            "--linmintol",
            str(linmintol)
        ])
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if sat is not None:
        cargs.extend([
            "--sat",
            str(sat)
        ])
    if conf_ref:
        cargs.append("--conf-ref")
    if no_bf:
        cargs.append("--no-bf")
    if bf_lim is not None:
        cargs.extend([
            "--bf-lim",
            str(bf_lim)
        ])
    if bf_nsamp is not None:
        cargs.extend([
            "--bf-nsamp",
            str(bf_nsamp)
        ])
    if no_smooth:
        cargs.append("--no-smooth")
    if ref_fwhm is not None:
        cargs.extend([
            "--ref-fwhm",
            str(ref_fwhm)
        ])
    if mov_oob:
        cargs.append("--mov-oob")
    if init_reg_save is not None:
        cargs.extend([
            "--init-reg-save",
            execution.input_file(init_reg_save)
        ])
    if init_reg_save_only is not None:
        cargs.extend([
            "--init-reg-save-only",
            execution.input_file(init_reg_save_only)
        ])
    if mat2par is not None:
        cargs.extend([
            "--mat2par",
            execution.input_file(mat2par)
        ])
    if mat2rot is not None:
        cargs.extend([
            "--mat2rot",
            execution.input_file(mat2rot)
        ])
    if par2mat is not None:
        cargs.extend([
            "--par2mat",
            par2mat
        ])
    if lrrev is not None:
        cargs.extend([
            "--lrrev",
            execution.input_file(lrrev)
        ])
    if landmarks is not None:
        cargs.extend([
            "--landmarks",
            *landmarks
        ])
    if rms is not None:
        cargs.extend([
            "--rms",
            *rms
        ])
    if movout is not None:
        cargs.extend([
            "--movout",
            execution.input_file(movout)
        ])
    if mov_idither is not None:
        cargs.extend([
            "--mov-idither",
            execution.input_file(mov_idither)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if version:
        cargs.append("--version")
    ret = MriCoregOutputs(
        root=execution.output_file("."),
        out_registration=execution.output_file(reg),
        out_params=execution.output_file(out_param_file) if (out_param_file is not None) else None,
        out_cost=execution.output_file(out_cost_file) if (out_cost_file is not None) else None,
        saved_init_reg=execution.output_file(pathlib.Path(init_reg_save).name) if (init_reg_save is not None) else None,
        saved_init_reg_only=execution.output_file(pathlib.Path(init_reg_save_only).name) if (init_reg_save_only is not None) else None,
        movout_volume=execution.output_file(pathlib.Path(movout).name) if (movout is not None) else None,
        mov_idither_volume=execution.output_file(pathlib.Path(mov_idither).name) if (mov_idither is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COREG_METADATA",
    "MriCoregOutputs",
    "mri_coreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLANIMATE_METADATA = Metadata(
    id="9c584c848682c3342403e26b38b71bebf6c12536.boutiques",
    name="fslanimate",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslanimateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslanimate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_animation: OutputPathType
    """The resulting animation file"""


def fslanimate(
    input_file: InputPathType,
    output_file: str,
    tmp_dir: str | None = None,
    runner: Runner | None = None,
) -> FslanimateOutputs:
    """
    Tool for creating animations from imaging data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input image file (e.g., input.nii.gz).
        output_file: Output file (e.g., output.gif).
        tmp_dir: Temporary directory for intermediate files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslanimateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLANIMATE_METADATA)
    cargs = []
    cargs.append("fslanimate")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if tmp_dir is not None:
        cargs.append(tmp_dir)
    ret = FslanimateOutputs(
        root=execution.output_file("."),
        output_animation=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLANIMATE_METADATA",
    "FslanimateOutputs",
    "fslanimate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STRBLAST_METADATA = Metadata(
    id="a2cee2c629b430408b17d4c3a5b48c6d60070e17.boutiques",
    name="strblast",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class StrblastOutputs(typing.NamedTuple):
    """
    Output object returned when calling `strblast(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def strblast(
    targetstring: str,
    input_files: list[InputPathType],
    new_char: str | None = None,
    new_string: str | None = None,
    unescape: bool = False,
    quiet: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> StrblastOutputs:
    """
    Finds exact copies of the target string in each of the input files, and replaces
    all characters with some junk string.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        targetstring: Target string to search for in the input files.
        input_files: Input files to search for the target string.
        new_char: Replace TARGETSTRING with CHAR (repeated).
        new_string: Replace TARGETSTRING with STRING.
        unescape: Parse TARGETSTRING for escaped characters (includes '\\t',\
            '\\n', '\\r').
        quiet: Do not report files with no strings found. Use -quiet -quiet to\
            avoid any reporting.
        help_: Show help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `StrblastOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STRBLAST_METADATA)
    cargs = []
    cargs.append("strblast")
    cargs.append(targetstring)
    cargs.extend([execution.input_file(f) for f in input_files])
    if new_char is not None:
        cargs.extend([
            "-new_char",
            new_char
        ])
    if new_string is not None:
        cargs.extend([
            "-new_string",
            new_string
        ])
    if unescape:
        cargs.append("-unescape")
    if quiet:
        cargs.append("-quiet")
    if help_:
        cargs.append("-help")
    ret = StrblastOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STRBLAST_METADATA",
    "StrblastOutputs",
    "strblast",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_SKELETON_METADATA = Metadata(
    id="25571f737489a24f1ca40f7027b3aa2c256d8dc2.boutiques",
    name="tbss_skeleton",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class TbssSkeletonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_skeleton(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType | None
    """Output skeleton image"""
    projected_4d_file: OutputPathType
    """Projected 4D data"""
    alt_4d_file: OutputPathType | None
    """Alternative 4D data"""
    alt_skeleton_file: OutputPathType | None
    """Alternative skeleton image"""
    debug2_image_outputs: OutputPathType | None
    """De-projected skelpoints points on skeleton back to all_FA space"""


def tbss_skeleton(
    input_image: InputPathType,
    output_image: str | None = None,
    skeleton_params: list[str] | None = None,
    alt_4d: InputPathType | None = None,
    alt_skeleton: InputPathType | None = None,
    debug_flag: bool = False,
    debug2_flag: InputPathType | None = None,
    runner: Runner | None = None,
) -> TbssSkeletonOutputs:
    """
    A tool for defining a 'skeleton' of white matter tracts in the brain to help
    compare them across subjects.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Input image.
        output_image: Output skeleton image.
        skeleton_params: Skeletonization parameters: <skel_thresh>\
            <distancemap> <search_rule_mask> <4Ddata> <projected_4Ddata>.
        alt_4d: Alternative 4D data (e.g., L1).
        alt_skeleton: Alternative skeleton.
        debug_flag: Switch on debugging image outputs.
        debug2_flag: De-project skelpoints points on skeleton back to all_FA\
            space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TbssSkeletonOutputs`).
    """
    if skeleton_params is not None and (len(skeleton_params) != 5): 
        raise ValueError(f"Length of 'skeleton_params' must be 5 but was {len(skeleton_params)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_SKELETON_METADATA)
    cargs = []
    cargs.append("tbss_skeleton")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if output_image is not None:
        cargs.extend([
            "-o",
            output_image
        ])
    if skeleton_params is not None:
        cargs.extend([
            "-p",
            *skeleton_params
        ])
    if alt_4d is not None:
        cargs.extend([
            "-a",
            execution.input_file(alt_4d)
        ])
    if alt_skeleton is not None:
        cargs.extend([
            "-s",
            execution.input_file(alt_skeleton)
        ])
    if debug_flag:
        cargs.append("-d")
    if debug2_flag is not None:
        cargs.extend([
            "-D",
            execution.input_file(debug2_flag)
        ])
    ret = TbssSkeletonOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image) if (output_image is not None) else None,
        projected_4d_file=execution.output_file("[PROJECTED_4D]"),
        alt_4d_file=execution.output_file(pathlib.Path(alt_4d).name) if (alt_4d is not None) else None,
        alt_skeleton_file=execution.output_file(pathlib.Path(alt_skeleton).name) if (alt_skeleton is not None) else None,
        debug2_image_outputs=execution.output_file(pathlib.Path(debug2_flag).name) if (debug2_flag is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_SKELETON_METADATA",
    "TbssSkeletonOutputs",
    "tbss_skeleton",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_STAT_CLUST_METADATA = Metadata(
    id="fc722addfbc175c71d3a318d604f19ee64fdb599.boutiques",
    name="3dStatClust",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dStatClustOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_stat_clust(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_head: OutputPathType | None
    """Output dataset header"""
    output_brick: OutputPathType | None
    """Output dataset brick"""


def v_3d_stat_clust(
    thresh: str,
    nclust: float,
    datasets: list[str],
    prefix: str | None = None,
    session_dir: str | None = None,
    verbose: bool = False,
    dist_cor: bool = False,
    runner: Runner | None = None,
) -> V3dStatClustOutputs:
    """
    Perform agglomerative hierarchical clustering for user specified parameter
    sub-bricks, for all voxels whose threshold statistic is above a user specified
    value.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        thresh: Threshold statistic from file tname. Only voxels whose\
            threshold statistic is greater than t in absolute value will be\
            considered. If file tname contains more than 1 sub-brick, the threshold\
            stat. sub-brick must be specified.
        nclust: Maximum number of clusters for output (= number of sub-bricks\
            in output dataset).
        datasets: Parameter datasets.
        prefix: Use 'pname' for the output dataset prefix name.
        session_dir: Use 'dir' for the output dataset session directory.
        verbose: Print out verbose output as the program proceeds.
        dist_cor: Statistical distance for correlated parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dStatClustOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_STAT_CLUST_METADATA)
    cargs = []
    cargs.append("3dStatClust")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if session_dir is not None:
        cargs.extend([
            "-session",
            session_dir
        ])
    if verbose:
        cargs.append("-verb")
    if dist_cor:
        cargs.append("-dist_cor")
    cargs.extend([
        "-thresh",
        thresh
    ])
    cargs.extend([
        "-nclust",
        str(nclust)
    ])
    cargs.extend(datasets)
    ret = V3dStatClustOutputs(
        root=execution.output_file("."),
        output_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        output_brick=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dStatClustOutputs",
    "V_3D_STAT_CLUST_METADATA",
    "v_3d_stat_clust",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TWOTO_COMPLEX_METADATA = Metadata(
    id="bf9493b3c937b76d0584de14a9b270a71cce9ca0.boutiques",
    name="3dTwotoComplex",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTwotoComplexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_twoto_complex(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_brick: OutputPathType | None
    """Output complex-valued dataset with prefix"""
    out_head: OutputPathType | None
    """Header for the complex-valued dataset"""


def v_3d_twoto_complex(
    dataset1: InputPathType,
    dataset2: InputPathType | None = None,
    prefix: str | None = None,
    ri: bool = False,
    mp: bool = False,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dTwotoComplexOutputs:
    """
    Converts 2 sub-bricks of input to a complex-valued dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset1: Input dataset (either as 1 dataset with 2 sub-bricks or 2\
            separate datasets).
        dataset2: Second input dataset (optional if 2 sub-bricks in the first\
            dataset).
        prefix: Prefix for the output dataset [default='cmplx'].
        ri: Specify that the 2 inputs are real and imaginary parts [this is the\
            default].
        mp: Specify that the 2 inputs are magnitude and phase [phase is in\
            radians].
        mask: Only output nonzero values where the mask dataset is nonzero.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTwotoComplexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TWOTO_COMPLEX_METADATA)
    cargs = []
    cargs.append("3dTwotoComplex")
    cargs.append(execution.input_file(dataset1))
    if dataset2 is not None:
        cargs.append(execution.input_file(dataset2))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if ri:
        cargs.append("-RI")
    if mp:
        cargs.append("-MP")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    ret = V3dTwotoComplexOutputs(
        root=execution.output_file("."),
        out_brick=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        out_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTwotoComplexOutputs",
    "V_3D_TWOTO_COMPLEX_METADATA",
    "v_3d_twoto_complex",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DKMEANS_METADATA = Metadata(
    id="4536293f2db1b50ebead4293161f46a508afd8a7.boutiques",
    name="3dkmeans",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dkmeansOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dkmeans(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cluster_membership: OutputPathType | None
    """Output volume for the cluster membership."""
    cluster_distance: OutputPathType | None
    """Output volume for the cluster distance measures."""
    distances_text_file: OutputPathType
    """Output text file containing distances between clusters."""
    centroids_text_file: OutputPathType
    """Output text file containing cluster centroids."""
    within_cluster_sum_text_file: OutputPathType
    """Output text file containing within cluster sum of distances."""
    max_distance_text_file: OutputPathType
    """Output text file containing maximum distance within each cluster."""
    voxel_distance_to_centroid: OutputPathType
    """Output text file containing distance from voxel to its centroid."""


def v_3dkmeans(
    input_: list[InputPathType],
    version: bool = False,
    mask: InputPathType | None = None,
    mask_range: list[float] | None = None,
    cmask: str | None = None,
    jobname: str | None = None,
    prefix: str | None = None,
    distance_measure: float | None = None,
    num_clusters: float | None = None,
    remap_method: str | None = None,
    labeltable: InputPathType | None = None,
    clabels: list[str] | None = None,
    clust_init: InputPathType | None = None,
    num_repeats: float | None = None,
    rsigs: InputPathType | None = None,
    verbose: bool = False,
    write_dists: bool = False,
    voxdbg: list[float] | None = None,
    seed: float | None = None,
    runner: Runner | None = None,
) -> V3dkmeansOutputs:
    """
    3d+t Clustering segmentation based on The C clustering library.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input data to be clustered. You can specify multiple filenames\
            in sequence and they will be concatenated internally.
        version:.
        mask: Dataset to be used as a mask; only voxels with nonzero values in\
            'mset' will be used.
        mask_range: Restrict the voxels from 'mset' to only those mask values\
            between 'a' and 'b' (inclusive).
        cmask: Execute the options enclosed in single quotes as a 3dcalc-like\
            program to produce a mask from the resulting 3D brick.
        jobname: Specify a different name for the output files. Default is\
            derived from the input file name.
        prefix: Specify a prefix for the output volumes. Default is the same as\
            jobname.
        distance_measure: Specifies distance measure for clustering. Supported\
            values: 0 (No clustering), 1 (Uncentered correlation distance), 2\
            (Pearson distance), 3 (Uncentered correlation distance, absolute\
            value), 4 (Pearson distance, absolute value), 5 (Spearman's rank\
            distance), 6 (Kendall's distance), 7 (Euclidean distance), 8\
            (City-block distance).
        num_clusters: Specify number of clusters.
        remap_method: Reassign clusters numbers based on METHOD: NONE\
            (default), COUNT, iCOUNT, MAG, iMAG.
        labeltable: Attach labeltable to clustering output.
        clabels: Provide a label for each cluster. Labels cannot start with\
            '-'.
        clust_init: Specify a dataset to initialize clustering. If provided,\
            sets -r 0.
        num_repeats: Number of times the k-means clustering algorithm is run.
        rsigs: Calculate distances from each voxel's signature to the\
            signatures in this multi-column file. No clustering done.
        verbose: Enable verbose mode.
        write_dists: Output text files containing various distance measures.
        voxdbg: Output debugging info for specified voxel (I J K).
        seed: Seed for the random number generator. Default is 1234567.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dkmeansOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DKMEANS_METADATA)
    cargs = []
    cargs.append("3dkmeans")
    if version:
        cargs.append("--version")
    cargs.extend([
        "-f",
        *[execution.input_file(f) for f in input_]
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mask_range is not None:
        cargs.extend([
            "-mrange",
            *map(str, mask_range)
        ])
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    if jobname is not None:
        cargs.extend([
            "-u",
            jobname
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if distance_measure is not None:
        cargs.extend([
            "-g",
            str(distance_measure)
        ])
    if num_clusters is not None:
        cargs.extend([
            "-k",
            str(num_clusters)
        ])
    if remap_method is not None:
        cargs.extend([
            "-remap",
            remap_method
        ])
    if labeltable is not None:
        cargs.extend([
            "-labeltable",
            execution.input_file(labeltable)
        ])
    if clabels is not None:
        cargs.extend([
            "-clabels",
            *clabels
        ])
    if clust_init is not None:
        cargs.extend([
            "-clust_init",
            execution.input_file(clust_init)
        ])
    if num_repeats is not None:
        cargs.extend([
            "-r",
            str(num_repeats)
        ])
    if rsigs is not None:
        cargs.extend([
            "-rsigs",
            execution.input_file(rsigs)
        ])
    if verbose:
        cargs.append("-verb")
    if write_dists:
        cargs.append("-write_dists")
    if voxdbg is not None:
        cargs.extend([
            "-voxdbg",
            *map(str, voxdbg)
        ])
    if seed is not None:
        cargs.extend([
            "-seed",
            str(seed)
        ])
    ret = V3dkmeansOutputs(
        root=execution.output_file("."),
        cluster_membership=execution.output_file(jobname + "_membership.nii.gz") if (jobname is not None) else None,
        cluster_distance=execution.output_file(jobname + "_distance.nii.gz") if (jobname is not None) else None,
        distances_text_file=execution.output_file("FILE.dis.1D"),
        centroids_text_file=execution.output_file("FILE.cen.1D"),
        within_cluster_sum_text_file=execution.output_file("FILE.info1.1D"),
        max_distance_text_file=execution.output_file("FILE.info2.1D"),
        voxel_distance_to_centroid=execution.output_file("FILE.vcd.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dkmeansOutputs",
    "V_3DKMEANS_METADATA",
    "v_3dkmeans",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSDCMDECOMPRESS_METADATA = Metadata(
    id="1c245eb1f1f4a476626056075ca7b223ab9946b1.boutiques",
    name="fsdcmdecompress",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsdcmdecompressOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsdcmdecompress(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """The decompressed DICOM file"""


def fsdcmdecompress(
    indcmfile: InputPathType,
    outdcmfile: str,
    dcmtk: bool = False,
    jpeg: bool = False,
    rle: bool = False,
    gdcm: bool = False,
    runner: Runner | None = None,
) -> FsdcmdecompressOutputs:
    """
    A tool for decompressing DICOM files using GDCM or DCMTK.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        indcmfile: Input DICOM file to decompress.
        outdcmfile: Output decompressed DICOM file.
        dcmtk: Use DCMTK for decompression (either dcmdrle.fs or dcmdjpeg.fs).
        jpeg: DICOM is JPEG compressed (ignored without --dcmtk).
        rle: DICOM is RLE compressed (ignored without --dcmtk).
        gdcm: Use GDCM for decompression (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsdcmdecompressOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSDCMDECOMPRESS_METADATA)
    cargs = []
    cargs.append("fsdcmdecompress")
    cargs.extend([
        "--i",
        execution.input_file(indcmfile)
    ])
    cargs.extend([
        "--o",
        outdcmfile
    ])
    if dcmtk:
        cargs.append("--dcmtk")
    if jpeg:
        cargs.append("--jpeg")
    if rle:
        cargs.append("--rle")
    if gdcm:
        cargs.append("--gdcm")
    ret = FsdcmdecompressOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(outdcmfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSDCMDECOMPRESS_METADATA",
    "FsdcmdecompressOutputs",
    "fsdcmdecompress",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_PAINT_METADATA = Metadata(
    id="7a8b84ee3337bcd66c42781ab9453c54416612bb.boutiques",
    name="mri_paint",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriPaintOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_paint(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_float: OutputPathType
    """The output .float file resulting from the painting process"""


def mri_paint(
    input_volume: InputPathType,
    input_surface: InputPathType,
    registration_file: InputPathType,
    output_float_file: str,
    image_offset: float | None = None,
    paint_surf_coords: bool = False,
    runner: Runner | None = None,
) -> MriPaintOutputs:
    """
    This program will paint average Talairach stats onto a surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: The input volume file.
        input_surface: The input surface file.
        registration_file: The registration file.
        output_float_file: The output .float file.
        image_offset: Set offset to use.
        paint_surf_coords: Paint using surface coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriPaintOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_PAINT_METADATA)
    cargs = []
    cargs.append("mri_paint")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(registration_file))
    cargs.append(output_float_file)
    if image_offset is not None:
        cargs.extend([
            "-imageoffset",
            str(image_offset)
        ])
    if paint_surf_coords:
        cargs.append("-S")
    ret = MriPaintOutputs(
        root=execution.output_file("."),
        output_float=execution.output_file(output_float_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_PAINT_METADATA",
    "MriPaintOutputs",
    "mri_paint",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_APARC2WMSEG_METADATA = Metadata(
    id="892ee2faaf430ffd543fbcdbbee1b1cfff8331fb.boutiques",
    name="mri_aparc2wmseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAparc2wmsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_aparc2wmseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_aparc2wmseg(
    subject: str,
    wmseg_file: str,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriAparc2wmsegOutputs:
    """
    A tool to convert aparc+aseg.mgz annotations into a white matter segmentation
    file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject identifier used in FreeSurfer.
        wmseg_file: File to store the output white matter segmentation.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAparc2wmsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_APARC2WMSEG_METADATA)
    cargs = []
    cargs.append("mri_aparc2wmseg")
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--wmseg",
        wmseg_file
    ])
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MriAparc2wmsegOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_APARC2WMSEG_METADATA",
    "MriAparc2wmsegOutputs",
    "mri_aparc2wmseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_TO_JPG_METADATA = Metadata(
    id="5bc8a9ac227d992d762dc5365725a949c90f5c17.boutiques",
    name="ConvertToJpg",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ConvertToJpgOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_to_jpg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jpg: OutputPathType
    """The converted JPG image."""


def convert_to_jpg(
    infile: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> ConvertToJpgOutputs:
    """
    A tool to convert NIfTI images to JPG format.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        infile: The input file in NIfTI format.
        outfile: The output file in JPG format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertToJpgOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_TO_JPG_METADATA)
    cargs = []
    cargs.append("ConvertToJpg" + execution.input_file(infile) + outfile)
    ret = ConvertToJpgOutputs(
        root=execution.output_file("."),
        output_jpg=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_TO_JPG_METADATA",
    "ConvertToJpgOutputs",
    "convert_to_jpg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCMSPLIT_METADATA = Metadata(
    id="3d5aa62fefcd13c6396a58e6fed84abe77250c1e.boutiques",
    name="dcmsplit",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DcmsplitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcmsplit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dcmsplit(
    dcm_dir: str,
    out_dir: str,
    copy_: bool = False,
    link: bool = False,
    split_name: bool = False,
    split_uid: bool = False,
    series_no: bool = False,
    series_plus: bool = False,
    dicom_tag: str | None = None,
    study_description: bool = False,
    runner: Runner | None = None,
) -> DcmsplitOutputs:
    """
    Splits DICOM files into separate folders based on a unique identifier (UID).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        dcm_dir: Directory containing the DICOM files.
        out_dir: Output directory for split DICOM files.
        copy_: Copy files instead of creating symbolic links.
        link: Link files instead of copying (default behavior).
        split_name: Split files by patient name instead of UID.
        split_uid: Split files by Study UID instead of name (default behavior).
        series_no: Split files by series number.
        series_plus: Split files by series number and either name or UID.
        dicom_tag: Split files by given DICOM tag (group element).
        study_description: Split files by Study Description.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DcmsplitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCMSPLIT_METADATA)
    cargs = []
    cargs.append("dcmsplit")
    cargs.extend([
        "--dcm",
        dcm_dir
    ])
    cargs.extend([
        "--o",
        out_dir
    ])
    if copy_:
        cargs.append("--cp")
    if link:
        cargs.append("--link")
    if split_name:
        cargs.append("--name")
    if split_uid:
        cargs.append("--uid")
    if series_no:
        cargs.append("--seriesno")
    if series_plus:
        cargs.append("--series+")
    if dicom_tag is not None:
        cargs.extend([
            "--t",
            dicom_tag
        ])
    if study_description:
        cargs.append("--studyDes")
    ret = DcmsplitOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCMSPLIT_METADATA",
    "DcmsplitOutputs",
    "dcmsplit",
]
